Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DMDServer ¶
type DMDServer struct {
// contains filtered or unexported fields
}
DMDServer is the Web Application for dependency-management-data (DMD)
type DatasetteConfig ¶
type DatasetteConfig struct {
// contains filtered or unexported fields
}
type SQLStudioConfig ¶ added in v0.98.0
type SQLStudioConfig struct {
// contains filtered or unexported fields
}
type UserConfig ¶
type UserConfig struct {
// Banner controls the display of a prominent banner across the top of every page on the application
Banner struct {
// HTML the HTML to render in that banner. Remember to add `<p>`s and/or other tags to wrap the text!
HTML template.HTML `json:"html"`
} `json:"banner"`
Footer struct {
// HTML the HTML to render in that footer. Remember to add `<p>`s and/or other tags to wrap the text!
HTML template.HTML `json:"html"`
} `json:"footer"`
// DatabaseMeta defines metadata about the underlying database
DatabaseMeta struct {
// GenerationTime defines the time that the database was generated
//
// Deprecated: Use the `dmd db meta finalise` command to set this metadata, instead of using this field
GenerationTime string `json:"generation_time"`
} `json:"database_meta"`
// AdditionalConfig contains any additional key-value configuration that will be presented as-is
AdditionalConfig map[string]string `json:"additional_config"`
}
Click to show internal directories.
Click to hide internal directories.